;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;		How does mispecification help/hurt?
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Just a plot of the true and mis-specified models:
(let ()
  (lines on)
  (domain -2 2)
  ;; logistic:
  (defun ff(x) (/ (exp x) (+ 1  (exp x))))
  ;; approximate arctan:
  (defun gg(x) (+ .5  (/ (atan x) pi)))
  (plot gg)
  (send my-plot :add-plot-item (list 'function #'ff))
  (postscript "misspec.ps")
  )

(let ()
  ;; Two helpers:
  (defun guess-alpha-a(x)
    (/ (* pi (+ (square x) 1)))
    )
  (defun guess-alpha-b(x)
    (* (gg x) (- 1 (gg x)))
    )

  ;; find alpha by linear regression:
  (regress (list 
	    (mapcar #'guess-alpha-b (rseq -2 2 20))
	    )
	   (mapcar #'guess-alpha-a (rseq -2 2 20))
	   ;; no intercept!
	   :intercept nil
	   )

  ;; find alpha by non-linear regression:
  (defun nreg-fun(theta)
    (let* (
	   (alpha (first theta))
	   (xx (rseq -2 2 20))
	   )
      (-
       (* alpha (guess-alpha-b xx))
       (guess-alpha-a xx)
       )
      )
    )
  (def nreg
       (nreg-model
	;; #'nreg-fun is the X-part of the non-linear regression
	#'nreg-fun
	;; (repeat 0 20) is the Y-part of the non-linear regression
	(repeat 0 20)
	;; .3 is ... the initial guess
	(list .03)
	)
       )
  )
	 
#|
(defun guess-alpha(x)
  (/ 
   (* pi 
      (+ (square x) 1)
      (gg x)
      (- 1 (gg x))
      )
   )
  )

(def alpha  (/ (integrate #'guess-alpha -2 2) 4))
|#
